==> open-cluster-management-policy-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1/CompliancePerClusterStatusFluent.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CompliancePerClusterStatusFluent<A extends CompliancePerClusterStatusFluent<A>> extends BaseFluent<A>{
  public CompliancePerClusterStatusFluent() {
  }
  public CompliancePerClusterStatusFluent(CompliancePerClusterStatus instance) {
    instance = (instance != null ? instance : new CompliancePerClusterStatus());

    if (instance != null) {
      this.withClustername(instance.getClustername());
      this.withClusternamespace(instance.getClusternamespace());
      this.withCompliant(instance.getCompliant());
      this.withClustername(instance.getClustername());
      this.withClusternamespace(instance.getClusternamespace());
      this.withCompliant(instance.getCompliant());
    }
  }
  private String clustername;
  private String clusternamespace;
  private String compliant;
  public String getClustername() {
    return this.clustername;
  }
  public A withClustername(String clustername) {
    this.clustername=clustername; return (A) this;
  }
  public boolean hasClustername() {
    return this.clustername != null;
  }
  public String getClusternamespace() {
    return this.clusternamespace;
  }
  public A withClusternamespace(String clusternamespace) {
    this.clusternamespace=clusternamespace; return (A) this;
  }
  public boolean hasClusternamespace() {
    return this.clusternamespace != null;
  }
  public String getCompliant() {
    return this.compliant;
  }
  public A withCompliant(String compliant) {
    this.compliant=compliant; return (A) this;
  }
  public boolean hasCompliant() {
    return this.compliant != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CompliancePerClusterStatusFluent that = (CompliancePerClusterStatusFluent) o;
    if (!java.util.Objects.equals(clustername, that.clustername)) return false;

    if (!java.util.Objects.equals(clusternamespace, that.clusternamespace)) return false;

    if (!java.util.Objects.equals(compliant, that.compliant)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clustername,  clusternamespace,  compliant,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clustername != null) { sb.append("clustername:"); sb.append(clustername + ","); }
    if (clusternamespace != null) { sb.append("clusternamespace:"); sb.append(clusternamespace + ","); }
    if (compliant != null) { sb.append("compliant:"); sb.append(compliant); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-policy-model-6.9.0-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1/CompliancePerClusterStatusFluent.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class CompliancePerClusterStatusFluent<A extends CompliancePerClusterStatusFluent<A>> extends BaseFluent<A>{
  public CompliancePerClusterStatusFluent() {
  }
  
  public CompliancePerClusterStatusFluent(CompliancePerClusterStatus instance) {
    this.copyInstance(instance);
  }
  private String clustername;
  private String clusternamespace;
  private String compliant;
  
  protected void copyInstance(CompliancePerClusterStatus instance) {
    instance = (instance != null ? instance : new CompliancePerClusterStatus());
  
    if (instance != null) {
        this.withClustername(instance.getClustername());
        this.withClusternamespace(instance.getClusternamespace());
        this.withCompliant(instance.getCompliant());
        this.withClustername(instance.getClustername());
        this.withClusternamespace(instance.getClusternamespace());
        this.withCompliant(instance.getCompliant());
      }
  }
  
  public String getClustername() {
    return this.clustername;
  }
  
  public A withClustername(String clustername) {
    this.clustername=clustername; return (A) this;
  }
  
  public boolean hasClustername() {
    return this.clustername != null;
  }
  
  public String getClusternamespace() {
    return this.clusternamespace;
  }
  
  public A withClusternamespace(String clusternamespace) {
    this.clusternamespace=clusternamespace; return (A) this;
  }
  
  public boolean hasClusternamespace() {
    return this.clusternamespace != null;
  }
  
  public String getCompliant() {
    return this.compliant;
  }
  
  public A withCompliant(String compliant) {
    this.compliant=compliant; return (A) this;
  }
  
  public boolean hasCompliant() {
    return this.compliant != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CompliancePerClusterStatusFluent that = (CompliancePerClusterStatusFluent) o;
    if (!java.util.Objects.equals(clustername, that.clustername)) return false;
  
    if (!java.util.Objects.equals(clusternamespace, that.clusternamespace)) return false;
  
    if (!java.util.Objects.equals(compliant, that.compliant)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(clustername,  clusternamespace,  compliant,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clustername != null) { sb.append("clustername:"); sb.append(clustername + ","); }
    if (clusternamespace != null) { sb.append("clusternamespace:"); sb.append(clusternamespace + ","); }
    if (compliant != null) { sb.append("compliant:"); sb.append(compliant); }
    sb.append("}");
    return sb.toString();
  }
  

}
